from xformula.syntax.core.features.wrappers.definitions.templates.wrap_one_or_more_of import (
    WrapOneOrMoreOf,
)
from xformula.syntax.core.features.wrappers.definitions.templates.wrap_zero_or_more_of import (
    WrapZeroOrMoreOf,
)

__all__ = [
    "WrapOneOrMoreOf",
    "WrapZeroOrMoreOf",
]
