from xformula.syntax.core.operations.abc import OperatorPrecedence
from xformula.syntax.core.operations.default_operator_precedences import (
    DEFAULT_OPERATOR_PRECEDENCES,
)

__all__ = [
    "DEFAULT_OPERATOR_PRECEDENCES",
    "OperatorPrecedence",
]
