from xformula.syntax.core.features.operations.definitions.non_terminals.operand import (
    Operand,
)
from xformula.syntax.core.features.operations.definitions.non_terminals.operation import (
    Operation,
)

__all__ = [
    "Operand",
    "Operation",
]
