from xformula.syntax.core.features.mappings.definitions.non_terminals.dict import Dict
from xformula.syntax.core.features.mappings.definitions.non_terminals.dict_pair import (
    DictPair,
)

__all__ = [
    "Dict",
    "DictPair",
]
